==> openshift-model-console-5.11.2-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleYAMLSampleSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.TypeMeta;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ConsoleYAMLSampleSpecFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.ConsoleYAMLSampleSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.ConsoleYAMLSampleSpecFluent<A>{
  public ConsoleYAMLSampleSpecFluentImpl() {
  }
  public ConsoleYAMLSampleSpecFluentImpl(io.fabric8.openshift.api.model.console.v1.ConsoleYAMLSampleSpec instance) {
    this.withDescription(instance.getDescription()); 
    this.withSnippet(instance.getSnippet()); 
    this.withTargetResource(instance.getTargetResource()); 
    this.withTitle(instance.getTitle()); 
    this.withYaml(instance.getYaml()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String description;
  private java.lang.Boolean snippet;
  private io.fabric8.kubernetes.api.model.TypeMeta targetResource;
  private java.lang.String title;
  private java.lang.String yaml;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDescription() {
    return this.description;
  }
  public A withDescription(java.lang.String description) {
    this.description=description; return (A) this;
  }
  public java.lang.Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0) {
    return (A)withDescription(new String(arg0));
  }
  public java.lang.Boolean getSnippet() {
    return this.snippet;
  }
  public A withSnippet(java.lang.Boolean snippet) {
    this.snippet=snippet; return (A) this;
  }
  public java.lang.Boolean hasSnippet() {
    return this.snippet != null;
  }
  public io.fabric8.kubernetes.api.model.TypeMeta getTargetResource() {
    return this.targetResource;
  }
  public A withTargetResource(io.fabric8.kubernetes.api.model.TypeMeta targetResource) {
    this.targetResource=targetResource; return (A) this;
  }
  public java.lang.Boolean hasTargetResource() {
    return this.targetResource != null;
  }
  public A withNewTargetResource(java.lang.String apiVersion,java.lang.String kind) {
    return (A)withTargetResource(new TypeMeta(apiVersion, kind));
  }
  public java.lang.String getTitle() {
    return this.title;
  }
  public A withTitle(java.lang.String title) {
    this.title=title; return (A) this;
  }
  public java.lang.Boolean hasTitle() {
    return this.title != null;
  }
  
  /**
   * Method is deprecated. use withTitle instead.
   */
  @java.lang.Deprecated
  public A withNewTitle(java.lang.String arg0) {
    return (A)withTitle(new String(arg0));
  }
  public java.lang.String getYaml() {
    return this.yaml;
  }
  public A withYaml(java.lang.String yaml) {
    this.yaml=yaml; return (A) this;
  }
  public java.lang.Boolean hasYaml() {
    return this.yaml != null;
  }
  
  /**
   * Method is deprecated. use withYaml instead.
   */
  @java.lang.Deprecated
  public A withNewYaml(java.lang.String arg0) {
    return (A)withYaml(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleYAMLSampleSpecFluentImpl that = (ConsoleYAMLSampleSpecFluentImpl) o;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (snippet != null ? !snippet.equals(that.snippet) :that.snippet != null) return false;
    if (targetResource != null ? !targetResource.equals(that.targetResource) :that.targetResource != null) return false;
    if (title != null ? !title.equals(that.title) :that.title != null) return false;
    if (yaml != null ? !yaml.equals(that.yaml) :that.yaml != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  snippet,  targetResource,  title,  yaml,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-console-5.12.3-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleYAMLSampleSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.TypeMeta;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ConsoleYAMLSampleSpecFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.ConsoleYAMLSampleSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.ConsoleYAMLSampleSpecFluent<A>{
  public ConsoleYAMLSampleSpecFluentImpl() {
  }
  public ConsoleYAMLSampleSpecFluentImpl(io.fabric8.openshift.api.model.console.v1.ConsoleYAMLSampleSpec instance) {
    this.withDescription(instance.getDescription()); 
    this.withSnippet(instance.getSnippet()); 
    this.withTargetResource(instance.getTargetResource()); 
    this.withTitle(instance.getTitle()); 
    this.withYaml(instance.getYaml()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String description;
  private java.lang.Boolean snippet;
  private io.fabric8.kubernetes.api.model.TypeMeta targetResource;
  private java.lang.String title;
  private java.lang.String yaml;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDescription() {
    return this.description;
  }
  public A withDescription(java.lang.String description) {
    this.description=description; return (A) this;
  }
  public java.lang.Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0) {
    return (A)withDescription(new String(arg0));
  }
  public java.lang.Boolean getSnippet() {
    return this.snippet;
  }
  public A withSnippet(java.lang.Boolean snippet) {
    this.snippet=snippet; return (A) this;
  }
  public java.lang.Boolean hasSnippet() {
    return this.snippet != null;
  }
  public io.fabric8.kubernetes.api.model.TypeMeta getTargetResource() {
    return this.targetResource;
  }
  public A withTargetResource(io.fabric8.kubernetes.api.model.TypeMeta targetResource) {
    this.targetResource=targetResource; return (A) this;
  }
  public java.lang.Boolean hasTargetResource() {
    return this.targetResource != null;
  }
  public A withNewTargetResource(java.lang.String apiVersion,java.lang.String kind) {
    return (A)withTargetResource(new TypeMeta(apiVersion, kind));
  }
  public java.lang.String getTitle() {
    return this.title;
  }
  public A withTitle(java.lang.String title) {
    this.title=title; return (A) this;
  }
  public java.lang.Boolean hasTitle() {
    return this.title != null;
  }
  
  /**
   * Method is deprecated. use withTitle instead.
   */
  @java.lang.Deprecated
  public A withNewTitle(java.lang.String arg0) {
    return (A)withTitle(new String(arg0));
  }
  public java.lang.String getYaml() {
    return this.yaml;
  }
  public A withYaml(java.lang.String yaml) {
    this.yaml=yaml; return (A) this;
  }
  public java.lang.Boolean hasYaml() {
    return this.yaml != null;
  }
  
  /**
   * Method is deprecated. use withYaml instead.
   */
  @java.lang.Deprecated
  public A withNewYaml(java.lang.String arg0) {
    return (A)withYaml(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleYAMLSampleSpecFluentImpl that = (ConsoleYAMLSampleSpecFluentImpl) o;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (snippet != null ? !snippet.equals(that.snippet) :that.snippet != null) return false;
    if (targetResource != null ? !targetResource.equals(that.targetResource) :that.targetResource != null) return false;
    if (title != null ? !title.equals(that.title) :that.title != null) return false;
    if (yaml != null ? !yaml.equals(that.yaml) :that.yaml != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  snippet,  targetResource,  title,  yaml,  additionalProperties,  super.hashCode());
  }
  
}
